@@ -40,7 +40,7 @@
 #' @export
 summary.TLMoments <- function(object, ci.level = .9, ...) {
   if (length(ci.level) != 1 | !is.numeric(ci.level)) stop("ci must be a numeric vector of length 1. ")
-  if (!("TLMoments" %in% class(object))) stop("First argument has to be of class TLMoments. ")
+  if (!inherits(object, "TLMoments")) stop("First argument has to be of class TLMoments. ")
 
   UseMethod("summary.TLMoments", object$lambdas)
 }
